Willpyre 
========

Willpyre provides abstraction over ASGI.
It supports HTTP without external dependencies.
Websockets support is yet to come.

.. admonition :: Micro-framework

   Willpyre is micro, but it does not mean it is not capable of doing.
   It means, it lets you choose anything and runs with anything.

The quick starts provides you with information about the components.
It gives some basic examples as well.
The documentation covers most of the basic parts of the code. 
Extending the components, ``startup`` and ``shutdown`` tasks, custom error responses, etc.
are present in the "advanced" section.


--------
Contents
--------

.. toctree ::
   installation
   quick_start
   middleware
   advanced
   documentation/index



